<?php

/**
 * @file
 * Contains \Drupal\field_ui_ajax\Form\FieldStorageConfigAjaxEditForm.
 */

namespace Drupal\field_ui_ajax\Form;

use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\field\Entity\FieldConfig;
use Drupal\field_ui\FieldUI;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;
use Drupal\field_ui\Form\FieldStorageConfigEditForm;
use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\HtmlCommand;
use Drupal\Core\Ajax\InvokeCommand;
use Drupal\Core\Ajax\OpenDialogCommand;
use Drupal\field_ui_ajax\Component\Utility\HtmlExtra;

/**
 * Provides a form for the "field storage" edit page.
 */
class FieldStorageConfigAjaxEditForm extends FieldStorageConfigEditForm {

  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state) {
    $form = parent::form($form, $form_state);

    if (HtmlExtra::getIsAjax()) {
      $form['intro'] = [
        '#weight' => -1000,
        '#markup' => '<h2>' . $form['#title'] . '</h2>',
      ];
    }

    return $form;
  }

  /**
   * {@inheritdoc}
   * Add the cancel action and the AJAX submit handler.
   */
  protected function actions(array $form, FormStateInterface $form_state) {
    $actions = parent::actions($form, $form_state);

    if (HtmlExtra::getIsAjax()) {
      $selector = 'js-' . str_replace(['.', '_'], '-', $form_state->getBuildInfo()['args'][0]);
      $actions['cancel'] = [
        '#markup' => '<a href="" class="button js-field-ui-toggle" data-field-ui-show=".' . $selector . '" data-field-ui-hide=".' . $selector . '-storage-form">' . t('Cancel') . '</a>',
        '#weight' => 6,
      ];
      $actions['submit']['#ajax'] = [
        'callback' => '::configStorageAjaxEditFormSubmit',
      ];
    }

    return $actions;
  }

  /**
   * Ajax callback for the "Save field settings" button.
   *
   * This hides the form and show back the row that contains field information.
   */
  public static function configStorageAjaxEditFormSubmit(array $form, FormStateInterface $form_state) {
    $response = new AjaxResponse();
    $selector = 'js-' . str_replace(['.', '_'], '-', $form_state->getBuildInfo()['args'][0]);

    if ($form_state->hasAnyErrors()) {
      $build = [
        '#prefix' => '<div>',
        '#suffix' => '</div>',
        'messages' => [
          '#type' => 'status_messages',
        ],
        'form' => $form,
      ];
      $response->addCommand(new HtmlCommand(
        '.' . $selector . '-storage-form td',
        $build
      ));
    }
    else {
      // Remove previous validation error messages
      $response->addCommand(new InvokeCommand(
        '.messages',
        'remove'
      ));
      // Remove the error class from the invalid elements
      $response->addCommand(new InvokeCommand(
        '.' . $selector . '-storage-form input, .' . $selector . '-storage-form select',
        'removeClass',
        ['error']
      ));
      // Remove the invalid aria attribute
      $response->addCommand(new InvokeCommand(
        '.' . $selector . '-storage-form input, .' . $selector . '-storage-form select',
        'removeAttr',
        ['aria-invalid']
      ));
      $response->addCommand(new InvokeCommand(
        '.' . $selector . '-storage-form',
        'addClass',
        ['js-field-ui-hidden']
      ));
      $response->addCommand(new InvokeCommand(
        '.' . $selector,
        'removeClass',
        ['js-field-ui-hidden']
      ));
      // Show messages in a dialog.
      $response->addCommand(new OpenDialogCommand(
        '#field-ui-ajax-dialog',
        NULL,
        ['#type' => 'status_messages'],
        ['width' => '90%']
      ));
    }
    return $response;
  }

}
